@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0412';
+$VERSION = '2.0413';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -310,6 +310,46 @@ Interface (DBI)
     $rc = $dbh->func('reload', 'admin');
 
 
+=head1 EXAMPLE
+
+  #!/usr/bin/perl
+
+  use strict;
+  use DBI();
+
+  # Connect to the database.
+  my $dbh = DBI->connect("DBI:mysql:database=test;host=localhost",
+                         "joe", "joe's password",
+                         {'RaiseError' => 1});
+
+  # Drop table 'foo'. This may fail, if 'foo' doesn't exist.
+  # Thus we put an eval around it.
+  eval { $dbh->do("DROP TABLE foo") };
+  print "Dropping foo failed: $@\n" if $@;
+
+  # Create a new table 'foo'. This must not fail, thus we don't
+  # catch errors.
+  $dbh->do("CREATE TABLE foo (id INTEGER, name VARCHAR(20)");
+
+  # INSERT some data into 'foo'. We are using $dbh->quote() for
+  # quoting the name.
+  $dbh->do("INSERT INTO foo VALUES (1, " . $dbh->quote("Tim") . ")");
+
+  # Same thing, but using placeholders
+  $dbh->do("INSERT INTO foo VALUES (?, ?)", undef, 2, "Jochen");
+
+  # Now retrieve data from the table.
+  my $sth = $dbh->prepare("SELECT * FROM foo");
+  $sth->execute();
+  while (my $ref = $sth->fetchrow_hashref()) {
+    print "Found a row: id = $ref->{'id'}, name = $ref->{'name'}\n";
+  }
+  $sth->finish();
+
+  # Disconnect from the database.
+  $dbh->disconnect();
+
+
 =head1 DESCRIPTION
 
 B<DBD::mysql> and B<DBD::mSQL> are the Perl5 Database Interface drivers
@@ -326,7 +366,7 @@ them. :-)
 In what follows we first discuss the use of DBD::mysql and DBD::mSQL,
 because this is what you will need the most. For installation, see the
 sections on L<INSTALLATION>, L<WIN32 INSTALLATION>, L<KNOWN PROBLEMS>
-and L<KNOWN BUGS> below. See L<EXAMPLE> for a simple example below.
+and L<KNOWN BUGS> below. See L<EXAMPLE> for a simple example above.
 
 From perl you activate the interface with the statement
 
@@ -989,45 +1029,6 @@ to configure. See the section on I<How to make a threadsafe client> in
 the manual.
 
 
-=head1 EXAMPLE
-
-  #!/usr/bin/perl
-
-  use strict;
-  use DBI();
-
-  # Connect to the database.
-  my $dbh = DBI->connect("DBI:mysql:database=test;host=localhost",
-                         "joe", "joe's password",
-                         {'RaiseError' => 1});
-
-  # Drop table 'foo'. This may fail, if 'foo' doesn't exist.
-  eval { $dbh->do("DROP TABLE foo") };
-  print "Dropping foo failed: $@\n" if $@;
-
-  # Create a new table 'foo'. This must not fail, thus we don't
-  # catch errors.
-  $dbh->do("CREATE TABLE foo (id INTEGER, name VARCHAR(20)");
-
-  # INSERT some data into 'foo'. We are using $dbh->quote() for
-  # quoting the name.
-  $dbh->do("INSERT INTO foo VALUES (1, " . $dbh->quote("Tim") . ")");
-
-  # Same thing, but using placeholders
-  $dbh->do("INSERT INTO foo VALUES (?, ?)", undef, 2, "Jochen");
-
-  # Now retrieve data from the table.
-  my $sth = $dbh->prepare("SELECT * FROM foo");
-  $sth->execute();
-  while (my $ref = $sth->fetchrow_hashref()) {
-    print "Found a row: id = $ref->{'id'}, name = $ref->{'name'}\n";
-  }
-  $sth->finish();
-
-  # Disconnect from the database.
-  $dbh->disconnect();
-
-
 =head1 INSTALLATION
 
 Windows users may skip this section and pass over to L<WIN32
@@ -1060,14 +1061,14 @@ need to fetch the archives from any CPAN mirror, for example
 The following archives are required (version numbers may have
 changed, I choose those which are current as of this writing):
 
-  DBI/DBI-1.06.tar.gz
+  DBI/DBI-1.13.tar.gz
   Data/Data-ShowTable-3.3.tar.gz
-  DBD/Msql-Mysql-modules-1.2017.tar.gz
+  DBD/Msql-Mysql-modules-1.2217.tar.gz
 
 Then enter the following commands:
 
-  gzip -cd DBI-1.06.tar.gz | tar xf -
-  cd DBI-1.06
+  gzip -cd DBI-1.13.tar.gz | tar xf -
+  cd DBI-1.13
   perl Makefile.PL
   make
   make test
@@ -1081,8 +1082,8 @@ Then enter the following commands:
   make install  # Don't try make test, the test suite is broken
 
   cd ..
-  gzip -cd Msql-Mysql-modules-1.2017.tar.gz | tar xf -
-  cd Msql-Mysql-modules-1.2017
+  gzip -cd Msql-Mysql-modules-1.2217.tar.gz | tar xf -
+  cd Msql-Mysql-modules-1.2217
   perl Makefile.PL
   make
   make test
@@ -1110,11 +1111,17 @@ within "make" or "make test".
 I have never attempted to install DBD::mSQL under Win32, so this is only
 for MySQL. If anyone succeeds, please let me know what you did.
 
-If you are using the ActiveState port of Perl, there's a binary
-package of DBD::mysql available at www.tcx.se, see the download
-page. This can be installed with I<ppm>. Otherwise it is recommended
-to use a binary distribution of Perl that already includes DBD::mysql.
-For example you find one at www.tcx.se.
+If you are using ActivePerl, you may use ppm to install DBD-mysql.
+For Perl 5.6, please do
+
+ ppm
+ install ftp://ftp.de.uu.net/pub/CPAN/authors/id/JWIED/DBD-mysql-1.2212.x86.ppd
+
+That should do. For Perl 5.005, ActiveState offers a package and you can
+simply do
+
+ ppm
+ install DBD-mysql
 
 Otherwise you definitely *need* a C compiler. And it *must* be the same
 compiler that was being used for compiling Perl itself. If you don't
@@ -1133,6 +1140,28 @@ have been required for me:
 
 =item -
 
+The current Perl versions (5.6, as of this writing) do have a problem
+with detecting the C libraries. I recommend to apply the following
+patch:
+
+  *** c:\Perl\lib\ExtUtils\Liblist.pm.orig Sat Apr 15 20:03:40 2000
+  --- c:\Perl\lib\ExtUtils\Liblist.pm      Sat Apr 15 20:03:45 2000
+  ***************
+  *** 230,235 ****
+  --- 230,239 ----
+      # add "$Config{installarchlib}/CORE" to default search path
+      push @libpath, "$Config{installarchlib}/CORE";
+
+  +     if ($VC  and  exists($ENV{LIB})  and  defined($ENV{LIB})) {
+  +       push(@libpath, split(/;/, $ENV{LIB}));
+  +     }
+  +
+      foreach (Text::ParseWords::quotewords('\s+', 0, $potential_libs)){
+
+        $thislib = $_;
+                                                                       
+=item -
+
 Extract sources into F<C:\>. This will create a directory F<C:\mysql>
 with subdirectories include and lib.
 
